@@ -127,6 +127,10 @@ def login_complete(request, redirect_field_name=REDIRECT_FIELD_NAME,
             return render(
                 request, template_name, {'message': 'Unkown user'}
             )
+        if getattr(user, 'requires_validated_email', False):
+            return render(
+                request, template_name, {'message': 'Validate your email'}
+            )
         if not user.is_active:
             return render(
                 request, template_name, {'message': 'Disabled account'}
